require('dotenv').config(); // Carrega as variáveis do arquivo .env
const axios = require('axios');
const fs = require('fs');

// Configurações do Apidog
const APIDOG_API_URL = 'https://api.apidog.com';
const API_DOG_API_KEY = 'APS-ndvhDX8kzM00k9KvAn1w17FRtiymrkgo';
const API_DOG_PROJECT_ID = 751641;
const API_VERSION = '2024-03-28';
const SWAGGER_FILE_PATH = './swagger-spec.json'; // Caminho do arquivo Swagger

// Verificar se o arquivo Swagger existe
if (!fs.existsSync(SWAGGER_FILE_PATH)) {
  console.error(`Arquivo Swagger ${SWAGGER_FILE_PATH} não encontrado!`);
  process.exit(1);
}

// Ler o conteúdo do arquivo Swagger
const swaggerData = fs.readFileSync(SWAGGER_FILE_PATH, 'utf-8');

// Configuração do cabeçalho e dados da requisição
const headers = {
  Authorization: `Bearer ${API_DOG_API_KEY}`,
  'X-Apidog-Api-Version': API_VERSION,
  'Content-Type': 'application/json',
};

// Função para enviar o arquivo Swagger
async function uploadSwagger() {
  const overwriteOptions = {
    targetEndpointFolderId: 0,
    targetSchemaFolderId: 0,
    endpointOverwriteBehavior: 'OVERWRITE_EXISTING',
    schemaOverwriteBehavior: 'OVERWRITE_EXISTING',
    updateFolderOfChangedEndpoint: false,
    prependBasePath: false,
  };

  const requestData = {
    swagger: JSON.parse(swaggerData),
    options: overwriteOptions,
  };

  try {
    const response = await axios.post(
      `${APIDOG_API_URL}/v1/projects/${API_DOG_PROJECT_ID}/import-openapi`,
      requestData,
      { headers },
    );

    console.log('Upload bem-sucedido!');
    console.log('Resposta do servidor:', response.data);
  } catch (error) {
    console.error('Erro ao enviar Swagger:');

    if (error.response) {
      console.error('Status:', error.response.status);
      console.error('Resposta:', error.response.data);
    } else {
      console.error('Erro geral:', error.message);
    }
  }
}

// Executar o upload
uploadSwagger();
